@@ -1395,7 +1395,6 @@ static void DumpParameter(const char* pTitle, CGparameter parameter, int nParame
     CGtype type;
     const char* pSemantic;
     int ii;
-    int jj;
     int nConnected;
     int nAnnotation;
     int nDimension;
@@ -1512,13 +1511,10 @@ static void DumpParameter(const char* pTitle, CGparameter parameter, int nParame
     }
 
     if (type == CG_ARRAY) {
-        nDimension = cgGetArrayDimension(parameter);
-        for (jj=0; jj<nDimension; ++jj) {
-            size = cgGetArraySize(parameter, jj);
-            for (ii=0; ii<size; ++ii) {
-                arrayParameter = cgGetArrayParameter(parameter, ii);
-                DumpParameter("ArrayParameter", arrayParameter, ii+1, container, parent);
-            }
+        size = cgGetArraySize(parameter, 0);
+        for (ii=0; ii<size; ++ii) {
+            arrayParameter = cgGetArrayParameter(parameter, ii);
+            DumpParameter("ArrayParameter", arrayParameter, ii+1, container, parent);
         }
     } else if (type == CG_STRUCT) {
         structParameter = cgGetFirstStructParameter(parameter);
