@@ -23,12 +23,15 @@ DLLEXPORT extern void traceInfo   (const char *, ...);
 DLLEXPORT extern void traceWarning(const char *, ...);
 DLLEXPORT extern void traceError  (const char *, ...);
 
-DLLEXPORT extern void traceBegin();
+DLLEXPORT extern int  traceEnabled(const char *);
+DLLEXPORT extern void traceBegin(void);
 DLLEXPORT extern void traceFunction(const char *);
 DLLEXPORT extern void traceInputParameter(const char *, const char *, ...);
+DLLEXPORT extern void tracePreCondition(void);
+DLLEXPORT extern void tracePostCondition(void);
 DLLEXPORT extern void traceOutputParameter(const char *, const char *, ...);
 DLLEXPORT extern void traceReturn(const char *, ...);
-DLLEXPORT extern void traceEnd();
+DLLEXPORT extern void traceEnd(void);
 
 #undef DLLEXPORT
 
@@ -42,12 +45,19 @@ extern int   indent;
 extern int   indentStep;
 extern char  indentBuffer[1024];
 extern int   base64;
-extern FILE *out;
-extern FILE *err;
+extern long  maxBlobSize;
+extern FILE *traceOut;
+extern FILE *traceErr;
+extern int   timeStamp;
 
 extern void updateIndent(int step);
 extern void traceInit(void);
 
+/* traceTime.c */
+
+extern int    timeInit(void);
+extern double timeElapsed(void);
+
 #endif
 
 #endif
